@@ -634,7 +634,6 @@ async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
         currentTry += 1
         try:
             response = None
-            # todo: session 做close操作
             async with aiohttp.ClientSession() as session:
                 response = await session.get(
                     url,
@@ -643,7 +642,7 @@ async def bAsyncHttpGet(url, headers=None, timeout=30, retry=3):
                 )
                 result = await response.read()
                 response.close()
-                await session.close()
+                # await session.close()
                 if not result:
                     continue
                 break
@@ -669,7 +668,6 @@ async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
         currentTry += 1
         try:
             response = None
-            # todo: session 做close操作
             async with aiohttp.ClientSession() as session:
                 response = await session.post(
                     url,
@@ -679,7 +677,7 @@ async def bAsyncHttpPost(url, data=None, headers=None, timeout=30, retry=3):
                 )
                 result = await response.read()
                 response.close()
-                await session.close()
+                # await session.close()
                 if not result:
                     continue
                 break
